@@ -1,7 +1,6 @@
 use super::Stack;
 use std::{
     future::Future,
-    marker::PhantomData,
     ops::{Deref, DerefMut},
     task::Context,
 };
@@ -9,23 +8,21 @@ use std::{
 #[repr(C)]
 pub struct AsyncStack<'a, 'b> {
     stack: Stack,
-    context: *mut Context<'b>,
+    context: &'a mut Context<'b>,
     suspended: bool,
-    _context: PhantomData<&'a Context<'b>>,
 }
 
 impl<'a, 'b> AsyncStack<'a, 'b> {
     pub fn new(capacity: usize, context: &'a mut Context<'b>) -> Self {
         Self {
             stack: Stack::new(capacity),
-            context: context as *mut Context<'b> as *mut Context<'b>,
+            context,
             suspended: false,
-            _context: Default::default(),
         }
     }
 
     pub fn context(&mut self) -> &mut Context<'b> {
-        unsafe { &mut *(self.context as *mut Context<'b>) }
+        self.context
     }
 
     pub fn suspend(&mut self, future: impl Future) {
@@ -57,6 +54,11 @@ impl<'a, 'b> DerefMut for AsyncStack<'a, 'b> {
     }
 }
 
+#[allow(dead_code)]
+extern "C" {
+    fn _test_async_stack_ffi_safety(_: *mut AsyncStack<'_, '_>);
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
