@@ -3,7 +3,9 @@ mod arc;
 mod boolean;
 mod box_any;
 mod closure;
+mod constants;
 pub mod cps;
+pub mod extra;
 mod none;
 mod number;
 mod string;
@@ -13,6 +15,7 @@ pub use arc::*;
 pub use boolean::*;
 pub use box_any::*;
 pub use closure::*;
+pub use constants::*;
 pub use none::*;
 pub use number::*;
 pub use string::*;
